==> jc-1.4.0.tar.gz: javax/naming/ldap/ControlFactory.h <==
// public abstract class javax.naming.ldap.ControlFactory

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class c9f9ee5767da2859 javax_naming_ldap_ControlFactory

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_naming_ldap_ControlFactory_H_
#define _JC_javax_naming_ldap_ControlFactory_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_Hashtable$object;
struct _jc_javax_naming_Context$object;
struct _jc_javax_naming_ldap_Control$object;

// Typedefs
typedef struct _jc_javax_naming_ldap_ControlFactory$sub_refs	_jc_javax_naming_ldap_ControlFactory$sub_refs;
typedef struct _jc_javax_naming_ldap_ControlFactory$sub_nonrefs	_jc_javax_naming_ldap_ControlFactory$sub_nonrefs;
typedef struct _jc_javax_naming_ldap_ControlFactory$refs	_jc_javax_naming_ldap_ControlFactory$refs;
typedef struct _jc_javax_naming_ldap_ControlFactory$nonrefs	_jc_javax_naming_ldap_ControlFactory$nonrefs;
typedef struct _jc_javax_naming_ldap_ControlFactory$object	_jc_javax_naming_ldap_ControlFactory$object;

typedef const struct _jc_javax_naming_ldap_ControlFactory$vmethods	_jc_javax_naming_ldap_ControlFactory$vmethods;
typedef const struct _jc_javax_naming_ldap_ControlFactory$vtable	_jc_javax_naming_ldap_ControlFactory$vtable;
typedef const struct _jc_javax_naming_ldap_ControlFactory$vtype	_jc_javax_naming_ldap_ControlFactory$vtype;

// Constructors
extern void _jc_javax_naming_ldap_ControlFactory$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_naming_ldap_ControlFactory$object *);

// Virtual methods
extern struct _jc_object *_jc_javax_naming_ldap_ControlFactory$method$getControlInstance$f25130b2d1d73a7c(_jc_env *, struct _jc_javax_naming_ldap_ControlFactory$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_javax_naming_ldap_ControlFactory$method_info$getControlInstance$f25130b2d1d73a7c;

// Static methods
extern struct _jc_object *_jc_javax_naming_ldap_ControlFactory$method$getControlInstance$094ee53c59d01232(_jc_env *, struct _jc_object *, struct _jc_object *, struct _jc_java_util_Hashtable$object *);

// Virtual methods structure
struct _jc_javax_naming_ldap_ControlFactory$vmethods {
	struct _jc_object	*(*getControlInstance$f25130b2d1d73a7c)(_jc_env *, struct _jc_javax_naming_ldap_ControlFactory$object *, struct _jc_object *);
};

// Vtable
struct _jc_javax_naming_ldap_ControlFactory$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_naming_ldap_ControlFactory$vmethods	javax_naming_ldap_ControlFactory;
};

// Vtype
struct _jc_javax_naming_ldap_ControlFactory$vtype {
	_jc_type			type;
	_jc_javax_naming_ldap_ControlFactory$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_naming_ldap_ControlFactory$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_naming_ldap_ControlFactory$refs {
    _jc_javax_naming_ldap_ControlFactory$sub_refs	javax_naming_ldap_ControlFactory;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_naming_ldap_ControlFactory$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_naming_ldap_ControlFactory$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_naming_ldap_ControlFactory$sub_nonrefs	javax_naming_ldap_ControlFactory;
};

// Object instance structure
struct _jc_javax_naming_ldap_ControlFactory$object {
	_jc_javax_naming_ldap_ControlFactory$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_naming_ldap_ControlFactory$vtype	*vtype;
	_jc_javax_naming_ldap_ControlFactory$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_naming_ldap_ControlFactory$vtype _jc_javax_naming_ldap_ControlFactory$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_naming_ldap_ControlFactory, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_naming_ldap_ControlFactory$class_object;

#endif	/* _JC_javax_naming_ldap_ControlFactory_H_ */

==> jc-1.4.6.tar.gz: javax/naming/ldap/ControlFactory.h <==
// public abstract class javax.naming.ldap.ControlFactory

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class c9f9ee5767da2859 javax_naming_ldap_ControlFactory

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_naming_ldap_ControlFactory_H_
#define _JC_javax_naming_ldap_ControlFactory_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_Hashtable$object;
struct _jc_javax_naming_Context$object;
struct _jc_javax_naming_ldap_Control$object;

// Typedefs
typedef struct _jc_javax_naming_ldap_ControlFactory$sub_refs	_jc_javax_naming_ldap_ControlFactory$sub_refs;
typedef struct _jc_javax_naming_ldap_ControlFactory$sub_nonrefs	_jc_javax_naming_ldap_ControlFactory$sub_nonrefs;
typedef struct _jc_javax_naming_ldap_ControlFactory$refs	_jc_javax_naming_ldap_ControlFactory$refs;
typedef struct _jc_javax_naming_ldap_ControlFactory$nonrefs	_jc_javax_naming_ldap_ControlFactory$nonrefs;
typedef struct _jc_javax_naming_ldap_ControlFactory$object	_jc_javax_naming_ldap_ControlFactory$object;

typedef const struct _jc_javax_naming_ldap_ControlFactory$vmethods	_jc_javax_naming_ldap_ControlFactory$vmethods;
typedef const struct _jc_javax_naming_ldap_ControlFactory$vtable	_jc_javax_naming_ldap_ControlFactory$vtable;
typedef const struct _jc_javax_naming_ldap_ControlFactory$vtype	_jc_javax_naming_ldap_ControlFactory$vtype;

// Constructors
extern void _jc_javax_naming_ldap_ControlFactory$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_naming_ldap_ControlFactory$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_object *_jc_javax_naming_ldap_ControlFactory$method$getControlInstance$f25130b2d1d73a7c(_jc_env *, struct _jc_javax_naming_ldap_ControlFactory$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_naming_ldap_ControlFactory$method_info$getControlInstance$f25130b2d1d73a7c;

// Static methods
extern struct _jc_object *_jc_javax_naming_ldap_ControlFactory$method$getControlInstance$094ee53c59d01232(_jc_env *, struct _jc_object *, struct _jc_object *, struct _jc_java_util_Hashtable$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_naming_ldap_ControlFactory$vmethods {
	struct _jc_object	*(*getControlInstance$f25130b2d1d73a7c)(_jc_env *, struct _jc_javax_naming_ldap_ControlFactory$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_naming_ldap_ControlFactory$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_naming_ldap_ControlFactory$vmethods	javax_naming_ldap_ControlFactory;
};

// Vtype
struct _jc_javax_naming_ldap_ControlFactory$vtype {
	_jc_type			type;
	_jc_javax_naming_ldap_ControlFactory$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_naming_ldap_ControlFactory$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_naming_ldap_ControlFactory$refs {
    _jc_javax_naming_ldap_ControlFactory$sub_refs	javax_naming_ldap_ControlFactory;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_naming_ldap_ControlFactory$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_naming_ldap_ControlFactory$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_naming_ldap_ControlFactory$sub_nonrefs	javax_naming_ldap_ControlFactory;
};

// Object instance structure
struct _jc_javax_naming_ldap_ControlFactory$object {
	_jc_javax_naming_ldap_ControlFactory$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_naming_ldap_ControlFactory$vtype	*vtype;
	_jc_javax_naming_ldap_ControlFactory$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_naming_ldap_ControlFactory$vtype _jc_javax_naming_ldap_ControlFactory$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_naming_ldap_ControlFactory, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_naming_ldap_ControlFactory$class_object;

#endif	/* _JC_javax_naming_ldap_ControlFactory_H_ */
